@@ -20,11 +20,11 @@ describe MultiJson::OptionsCache do
   end
 
   it "stores value in current cache after reset" do
-    described_class.fetch(:load, :foo) do
+    described_class.fetch(:load) do
       described_class.reset
       :bar
     end
 
-    expect(described_class.fetch(:load, :foo) { :baz }).to eq(:bar)
+    expect(described_class.fetch(:load, :baz)).to eq(:bar)
   end
 end
